from distutils.core import setup
from distutils.extension import Extension
from Pyrex.Distutils import build_ext

setup(
  name = 'Demos',
  ext_modules=[ 
    Extension("primes",       ["primes.pyx"]),
    Extension("spam",         ["spam.pyx"]),
    Extension("numeric_demo", ["numeric_demo.pyx"]),
    ],
  cmdclass = {'build_ext': build_ext}
)



#
#  This example demonstrates how to access the internals
#  of a Numeric array object.
#

cdef extern from "Numeric/arrayobject.h":

  struct PyArray_Descr:
    int type_num, elsize
    char type

  ctypedef class Numeric.ArrayType [object PyArrayObject]:
    cdef char *data
    cdef int nd
    cdef int *dimensions, *strides
    cdef object base
    cdef PyArray_Descr *descr
    cdef int flags

def print_2d_array(ArrayType a):
  print "Type:", chr(a.descr.type)
  if chr(a.descr.type) <> "f":
    raise TypeError("Float array required")
  if a.nd <> 2:
    raise ValueError("2 dimensional array required")
  cdef int nrows, ncols
  cdef float *elems, x
  nrows = a.dimensions[0]
  ncols = a.dimensions[1]
  elems = <float *>a.data
  hyphen = "-"
  divider = ("+" + 10 * hyphen) * ncols + "+"
  print divider
  for row in range(nrows):
    for col in range(ncols):
      x = elems[row * ncols + col]
      print "| %8f" % x,
    print "|"
    print divider



#
#  Example of an extension type.
#

cdef class Spam:

  cdef int amount

  def __new__(self):
    self.amount = 0

  def __dealloc__(self):
    print self.amount, "tons of spam is history."

  def get_amount(self):
    return self.amount

  def set_amount(self, new_amount):
    self.amount = new_amount

  def describe(self):
    print self.amount, "tons of spam!"



from distutils.core import setup
from distutils.extension import Extension
from Pyrex.Distutils import build_ext

setup(
  name = 'callback',
  ext_modules=[ 
    Extension("cheese", ["cheese.pyx", "cheesefinder.c"]),
    ],
  cmdclass = {'build_ext': build_ext}
)



from distutils.core import setup
from distutils.sysconfig import get_python_lib
import os
from Pyrex.Compiler.Version import version

compiler_dir = os.path.join(get_python_lib(prefix=''), 'Pyrex/Compiler')

if os.name == "posix":
    scripts = ["bin/pyrexc"]
else:
    scripts = ["pyrexc.py"]

setup(
  name = 'Pyrex', 
  version = version,
  url = 'http://www.cosc.canterbury.ac.nz/~greg/python/Pyrex/',
  author = 'Greg Ewing',
  author_email = 'greg@cosc.canterbury.ac.nz',
  scripts = scripts,
  packages=[
    'Pyrex',
    'Pyrex.Compiler',
    'Pyrex.Distutils',
    'Pyrex.Mac',
    'Pyrex.Plex'
    ],
  data_files=[
    (compiler_dir, ['Pyrex/Compiler/Lexicon.pickle'])
    ]
  )

